generate_points — Cartographie 04/07/2021 documentation

# `generate_points`

## Module Contents

### Functions

`takeFirst`(elem) | Return the first coordinate (x) of a point.
`takeSecond`(elem) | Return the second coordinate (y) of a point.
`generate_random_around`(number, polygon) | Generates random points around a polygon

generate_points.takeFirst(elem)

  Return the first coordinate (x) of a point. Args:

  > elem (int): a shapely point

  Retuns: the first coordinate (x) of a point

generate_points.takeSecond(elem)

  Return the second coordinate (y) of a point. Args:

  > elem (int): a shapely point

  Returns: the second coordinate (y) of a point

generate_points.generate_random_around(number, polygon)

  Generates random points around a polygon Args:

  > number (int): number of points to generate per side polygon (Polygon): the polygon around which you want to generate the points

  Returns: 4 lists of points generated for each side